"use strict";
var core_1 = require('@angular/core');
var tooltip_container_component_1 = require('./tooltip-container.component');
var tooltip_options_class_1 = require('./tooltip-options.class');
var components_helper_service_1 = require('../utils/components-helper.service');
var tooltip_config_1 = require('./tooltip.config');
/* tslint:disable */
/* tslint:enable */
var TooltipDirective = (function () {
    function TooltipDirective(viewContainerRef, componentsHelper, changeDetectorRef, renderer, elementRef, config) {
        this.placement = 'top';
        this.enable = true;
        this.animation = true;
        this.appendToBody = false;
        this.delay = 0;
        this.fadeDuration = 150;
        /* tslint:enable */
        this.tooltipStateChanged = new core_1.EventEmitter();
        this.visible = false;
        this.toggleOnShowListeners = [];
        this.viewContainerRef = viewContainerRef;
        this.componentsHelper = componentsHelper;
        this.changeDetectorRef = changeDetectorRef;
        this.renderer = renderer;
        this.elementRef = elementRef;
        this.config = config;
        this.configureOptions();
    }
    TooltipDirective.prototype.ngOnInit = function () {
        this.bindListeners();
    };
    TooltipDirective.prototype.configureOptions = function () {
        Object.assign(this, this.config);
    };
    TooltipDirective.prototype.bindListeners = function () {
        var tooltipElement = this.elementRef.nativeElement;
        var events = this.normalizeEventsSet(this.tooltipTrigger);
        /* tslint:disable */
        for (var i = 0; i < events.length; i++) {
            var listener = this.renderer.listen(tooltipElement, events[i], this.show.bind(this));
            this.toggleOnShowListeners.push(listener);
        }
        /* tslint:enable */
    };
    TooltipDirective.prototype.normalizeEventsSet = function (events) {
        if (typeof events === 'string') {
            return events.split(/[\s,]+/);
        }
        return events;
    };
    // params: event, target
    TooltipDirective.prototype.show = function (e) {
        var _this = this;
        this.preventAndStop(e);
        if (this.visible || !this.enable || this.delayTimeoutId) {
            return;
        }
        var showTooltip = function () {
            _this.visible = true;
            var options = new tooltip_options_class_1.TooltipOptions({
                content: _this.content,
                htmlContent: _this.htmlContent,
                placement: _this.placement,
                animation: _this.animation,
                appendToBody: _this.appendToBody,
                hostEl: _this.viewContainerRef.element,
                popupClass: _this.popupClass,
                context: _this.tooltipContext,
                trigger: _this.tooltipTrigger
            });
            if (_this.appendToBody) {
                _this.tooltip = _this.componentsHelper
                    .appendNextToRoot(tooltip_container_component_1.TooltipContainerComponent, tooltip_options_class_1.TooltipOptions, options);
            }
            else {
                var binding = core_1.ReflectiveInjector.resolve([
                    { provide: tooltip_options_class_1.TooltipOptions, useValue: options }
                ]);
                _this.tooltip = _this.componentsHelper
                    .appendNextToLocation(tooltip_container_component_1.TooltipContainerComponent, _this.viewContainerRef, binding);
            }
            _this.changeDetectorRef.markForCheck();
            _this.triggerStateChanged();
        };
        if (this.delay) {
            this.delayTimeoutId = setTimeout(function () { showTooltip(); }, this.delay);
        }
        else {
            showTooltip();
        }
    };
    // params event, target
    TooltipDirective.prototype.hide = function () {
        var _this = this;
        if (this.delayTimeoutId) {
            clearTimeout(this.delayTimeoutId);
            this.delayTimeoutId = undefined;
        }
        if (!this.visible) {
            return;
        }
        this.tooltip.instance.classMap.in = false;
        setTimeout(function () {
            _this.visible = false;
            _this.tooltip.destroy();
            _this.triggerStateChanged();
        }, this.fadeDuration);
    };
    TooltipDirective.prototype.triggerStateChanged = function () {
        this.tooltipStateChanged.emit(this.visible);
    };
    TooltipDirective.prototype.preventAndStop = function (event) {
        if (!event) {
            return;
        }
        event.preventDefault();
        event.stopPropagation();
    };
    TooltipDirective.prototype.ngOnDestroy = function () {
        var listeners = this.toggleOnShowListeners;
        /* tslint:disable */
        for (var i = 0; i < listeners.length; i++) {
            listeners[i].call(this);
        }
        /* tslint:enable */
    };
    TooltipDirective.decorators = [
        { type: core_1.Directive, args: [{
                    selector: '[tooltip], [tooltipHtml]',
                    exportAs: 'bs-tooltip'
                },] },
    ];
    /** @nocollapse */
    TooltipDirective.ctorParameters = [
        { type: core_1.ViewContainerRef, },
        { type: components_helper_service_1.ComponentsHelper, },
        { type: core_1.ChangeDetectorRef, },
        { type: core_1.Renderer, },
        { type: core_1.ElementRef, },
        { type: tooltip_config_1.TooltipConfig, },
    ];
    TooltipDirective.propDecorators = {
        'content': [{ type: core_1.Input, args: ['tooltip',] },],
        'htmlContent': [{ type: core_1.Input, args: ['tooltipHtml',] },],
        'placement': [{ type: core_1.Input, args: ['tooltipPlacement',] },],
        'isOpen': [{ type: core_1.Input, args: ['tooltipIsOpen',] },],
        'enable': [{ type: core_1.Input, args: ['tooltipEnable',] },],
        'animation': [{ type: core_1.Input, args: ['tooltipAnimation',] },],
        'appendToBody': [{ type: core_1.Input, args: ['tooltipAppendToBody',] },],
        'popupClass': [{ type: core_1.Input, args: ['tooltipClass',] },],
        'tooltipContext': [{ type: core_1.Input, args: ['tooltipContext',] },],
        'delay': [{ type: core_1.Input, args: ['tooltipPopupDelay',] },],
        'fadeDuration': [{ type: core_1.Input, args: ['tooltipFadeDuration',] },],
        'tooltipTrigger': [{ type: core_1.Input, args: ['tooltipTrigger',] },],
        'tooltipStateChanged': [{ type: core_1.Output },],
        'hide': [{ type: core_1.HostListener, args: ['mouseleave',] }, { type: core_1.HostListener, args: ['mouseout',] }, { type: core_1.HostListener, args: ['focusout',] }, { type: core_1.HostListener, args: ['blur',] },],
    };
    return TooltipDirective;
}());
exports.TooltipDirective = TooltipDirective;
